<?php
/*
 * $Horde: vacation/menu.php,v 1.1.1.1.2.1 2002/10/07 01:36:18 ericr Exp $
 *
 * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
 * Copyright 1999-2002 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('VACATION_BASE', dirname(__FILE__));
include_once VACATION_BASE . '/lib/base.php';
require_once HORDE_BASE . '/lib/Menu.php';

if ($prefs->getValue("frames_mode")  && ! preg_match("/frames_menu\.php$/", $PHP_SELF)) return;

/* Check for additional site-specific menu items (in config/menu.php). */
$additional_items = '';
if (@is_readable(VACATION_BASE . '/config/menu.php')) {
    include_once VACATION_BASE . '/config/menu.php';
    if (isset($_menu) && is_array($_menu)) {
        foreach ($_menu as $item) {
            $additional_items .= Menu::customItem($item);
        }
    }
}

require $registry->getTemplatePath() . '/menu/menu.inc';

/* Include the JavaScript for the help system (if enabled). */
if ($conf['user']['online_help'] && $browser->hasFeature('javascript')) {
    Help::javascript();
}

?>
